@@ -44,22 +44,11 @@ void init_signals_very_early (void);
 
 void reinit_alloc_early (void);
 void init_alloc_once_early (void);
-void reinit_eistring_early (void);
-void init_eistring_once_early (void);
 void init_elhash_once_early (void);
 void init_errors_once_early (void);
-void reinit_opaque_early (void);
 void init_opaque_once_early (void);
-void reinit_process_early (void);
-void reinit_symbols_early (void);
 void init_symbols_once_early (void);
 
-/* Reset the Lisp engine.  Called both at dump-time, run-time and
-   run-temacs-time; at dump-time, it's called early, before any of the
-   vars() or complex_vars() routines.  Currently does almost nothing. */
-
-void init_alloc_early (void);
-
 /* Called somewhat randomly -- at dump-time, in the middle of the vars()
    calls, and at run-time, just before the late initializations. */
 
@@ -202,27 +191,6 @@ void syms_of_widget (void);
 void syms_of_win32 (void);
 void syms_of_window (void);
 
-/* Initialize dynamic properties of objects (i.e. those properties not
-   initialized statically through a DEFINE_*_LISP_OBJECT declaration).
-   Dump time and post-pdump-load-time. */
-
-void buffer_objects_create (void);
-void bytecode_objects_create (void);
-void casetab_objects_create (void);
-void chartab_objects_create (void);
-void extent_objects_create (void);
-void face_objects_create (void);
-void frame_objects_create (void);
-void glyph_objects_create (void);
-void hash_table_objects_create (void);
-void lstream_objects_create (void);
-void mule_charset_objects_create (void);
-void rangetab_objects_create (void);
-void scrollbar_objects_create (void);
-void specifier_objects_create (void);
-void ui_gtk_objects_create (void);
-void window_objects_create (void);
-
 /* Initialize the console types (dump-time only for console_type_(),
    post-pdump-load-time only for reinit_). */
 
@@ -264,40 +232,25 @@ void console_type_create_select_gtk (void);
 void console_type_create_select_mswindows (void);
 void console_type_create_select_x (void);
 void console_type_create_stream (void);
-void reinit_console_type_create_stream (void);
 void console_type_create_toolbar_gtk (void);
 void console_type_create_toolbar_mswindows (void);
 void console_type_create_toolbar_x (void);
 void console_type_create_tty (void);
-void reinit_console_type_create_tty (void);
 void console_type_create_x (void);
-void reinit_console_type_create_x (void);
 
-/* Initialize the specifier types (dump-time only for specifier_type_(),
-   post-pdump-load-time only for reinit_). */
+/* Initialize the specifier types (dump-time only) */
 
 void specifier_type_create (void);
-void reinit_specifier_type_create (void);
 void specifier_type_create_gutter (void);
-void reinit_specifier_type_create_gutter (void);
 void specifier_type_create_image (void);
-void reinit_specifier_type_create_image (void);
 void specifier_type_create_fontcolor (void);
-void reinit_specifier_type_create_fontcolor (void);
 void specifier_type_create_toolbar (void);
-void reinit_specifier_type_create_toolbar (void);
-
-/* Initialize the coding system types (dump-time only for
-   coding_system_type_(), post-pdump-load-time only for reinit_). */
 
+/* Initialize the coding system types (dump-time only). */
 void coding_system_type_create (void);
-void reinit_coding_system_type_create (void);
 void coding_system_type_create_intl_win32 (void);
-void reinit_coding_system_type_create_intl_win32 (void);
 void coding_system_type_create_mule_coding (void);
-void reinit_coding_system_type_create_mule_coding (void);
 void coding_system_type_create_unicode (void);
-void reinit_coding_system_type_create_unicode (void);
 
 /* Initialize the structure types (dump-time only). */
 
@@ -317,13 +270,6 @@ void image_instantiator_format_create_glyphs_tty (void);
 void image_instantiator_format_create_glyphs_widget (void);
 void image_instantiator_format_create_glyphs_x (void);
 
-/* Initialize the lstream types (dump-time only). */
-
-void lstream_type_create (void);
-void lstream_type_create_file_coding (void);
-void lstream_type_create_mswindows_selectable (void);
-void lstream_type_create_print (void);
-
 /* Initialize process types */
 
 void process_type_create_nt (void);
@@ -350,10 +296,8 @@ void init_provide_once (void);
 
 void vars_of_abbrev (void);
 void vars_of_alloc (void);
-void reinit_vars_of_alloc (void);
 void vars_of_balloon_x (void);
 void vars_of_buffer (void);
-void reinit_vars_of_buffer (void);
 void vars_of_bytecode (void);
 void reinit_vars_of_bytecode (void);
 void vars_of_callint (void);
@@ -363,7 +307,6 @@ void vars_of_chartab (void);
 void vars_of_cmdloop (void);
 void vars_of_cmds (void);
 void vars_of_console (void);
-void reinit_vars_of_console (void);
 void vars_of_console_gtk (void);
 void vars_of_console_mswindows (void);
 void vars_of_console_stream (void);
@@ -374,7 +317,6 @@ void vars_of_database (void);
 void vars_of_debug (void);
 void reinit_vars_of_debug (void);
 void vars_of_device (void);
-void reinit_vars_of_device (void);
 void vars_of_device_gtk (void);
 void vars_of_device_mswindows (void);
 void vars_of_device_x (void);
@@ -394,21 +336,15 @@ void vars_of_emacs (void);
 void vars_of_eval (void);
 void reinit_vars_of_eval (void);
 void vars_of_event_Xt (void);
-void reinit_vars_of_event_Xt (void);
 void vars_of_event_gtk (void);
-void reinit_vars_of_event_gtk (void);
 void vars_of_event_mswindows (void);
-void reinit_vars_of_event_mswindows (void);
 void vars_of_event_stream (void);
 void reinit_vars_of_event_stream (void);
 void vars_of_event_tty (void);
-void reinit_vars_of_event_tty (void);
 void vars_of_events (void);
-void reinit_vars_of_events (void);
 void vars_of_extents (void);
 void vars_of_faces (void);
 void vars_of_file_coding (void);
-void reinit_vars_of_file_coding (void);
 void vars_of_fileio (void);
 #ifdef USE_C_FONT_LOCK
 void reinit_vars_of_fileio (void);
@@ -417,55 +353,44 @@ void vars_of_filelock (void);
 void vars_of_floatfns (void);
 void vars_of_fns (void);
 void vars_of_font_lock (void);
-void reinit_vars_of_font_lock (void);
 void vars_of_font_mgr (void);
 void vars_of_frame (void);
 void vars_of_frame_gtk (void);
 void vars_of_frame_mswindows (void);
-void reinit_vars_of_frame_mswindows (void);
 void vars_of_frame_tty (void);
 void vars_of_frame_x (void);
 void vars_of_glyphs (void);
-void reinit_vars_of_glyphs (void);
 void vars_of_glyphs_eimage (void);
 void vars_of_glyphs_gtk (void);
 void vars_of_glyphs_mswindows (void);
 void vars_of_glyphs_widget (void);
-void reinit_vars_of_glyphs_widget (void);
 void vars_of_glyphs_x (void);
 void vars_of_gpmevent (void);
 void vars_of_gui (void);
 void vars_of_gui_gtk (void);
 void vars_of_gui_x (void);
-void reinit_vars_of_gui_x (void);
 void vars_of_gutter (void);
 void vars_of_indent (void);
 void vars_of_input_method_motif (void);
 void vars_of_input_method_xlib (void);
 void vars_of_insdel (void);
-void reinit_vars_of_insdel (void);
 void vars_of_intl (void);
 void vars_of_intl_win32 (void);
 void vars_of_keymap (void);
 void vars_of_lread (void);
-void reinit_vars_of_lread (void);
 void vars_of_lstream (void);
+void reinit_vars_of_lstream (void);
 void vars_of_macros (void);
 void vars_of_md5 (void);
 void vars_of_menubar (void);
 void vars_of_menubar_gtk (void);
-void reinit_vars_of_menubar_gtk (void);
 void vars_of_menubar_mswindows (void);
 void vars_of_menubar_x (void);
-void reinit_vars_of_menubar_x (void);
 void vars_of_minibuf (void);
-void reinit_vars_of_minibuf (void);
 void vars_of_module (void);
-void reinit_vars_of_module (void);
 void vars_of_mule_ccl(void);
 void vars_of_mule_charset (void);
 void vars_of_mule_coding (void);
-void reinit_vars_of_mule_coding (void);
 void vars_of_mule_wnn (void);
 void reinit_vars_of_mule_wnn (void);
 void vars_of_nt (void);
@@ -480,7 +405,6 @@ void vars_of_fontcolor_tty (void);
 void vars_of_fontcolor_x (void);
 EXTERN_C void vars_of_postgresql (void);
 void vars_of_print (void);
-void reinit_vars_of_print (void);
 void reinit_complex_vars_of_print (void);
 void vars_of_process (void);
 void vars_of_process_nt (void);
@@ -494,14 +418,12 @@ void vars_of_scrollbar (void);
 void vars_of_scrollbar_gtk (void);
 void vars_of_scrollbar_mswindows (void);
 void vars_of_scrollbar_x (void);
-void reinit_vars_of_scrollbar_x (void);
 void vars_of_search (void);
 void reinit_vars_of_search (void);
 void vars_of_select (void);
 void vars_of_select_gtk (void);
 void vars_of_select_mswindows (void);
 void vars_of_select_x (void);
-void reinit_vars_of_select_x (void);
 void vars_of_sound (void);
 void vars_of_specifier (void);
 void vars_of_sunpro (void);
@@ -515,11 +437,9 @@ void vars_of_toolbar_gtk (void);
 void vars_of_tooltalk (void);
 void vars_of_ui_gtk (void);
 void vars_of_undo (void);
-void reinit_vars_of_undo (void);
 void vars_of_unicode (void);
 void vars_of_win32 (void);
 void vars_of_window (void);
-void reinit_vars_of_window (void);
 
 /* Initialize specifier variables (dump-time only). */
 
@@ -588,7 +508,6 @@ void init_intl_win32 (void);
 void init_lread (void);
 void init_macros (void);
 void init_mule_charset (void);
-void init_mule_coding (void);
 void init_mswindows_environment (void);
 void init_nt (void);
 void init_postgresql_from_environment (void);
